==> nextcloud-16.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/nl.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "An error occurred while generating your backup codes" : "Er trad een fout op bij het genereren van je backup codes",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Dit zijn je back-upcodes. Bewaar ze en/of druk ze alsjeblieft af, want je ze niet later nog een keer opvragen.",
    "Save backup codes" : "Bewaren backup code",
    "Print backup codes" : "Afdrukken backup code",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Backup codes zijn gegenereerd. {used} van {{total}} codes zijn gebruikt.",
    "Regenerate backup codes" : "Regenereer backup code",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "Als je backup codes opnieuw genereert, worden oude codes automatisch ongeldig gemaakt.",
    "Generate backup codes" : "Genereer backup code",
    "You created two-factor backup codes for your account" : "Je creëerde tweefactor back-up codes voor je account",
    "Second-factor backup codes" : "Twee-factor backup code",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Je hebt tweefactor authenticatie ingeschakeld, maar nog geen backup codes gegenereerd. Doe dat eerst, voor het geval dat je toegang tot je tweede factor apparaat kwijt bent.",
    "Backup code" : "Backup code",
    "Use backup code" : "Gebruik backup code",
    "Two factor backup codes" : "Twee-factor backupcode",
    "A two-factor auth backup codes provider" : "Een two-factor auth backup codes provider",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Gebruik een van de backupcodes die je bewaarde bij het inschakelen van de twee-factor authenticatie.",
    "Submit" : "Verwerken",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Backup codes zijn gegenereerd. {{used}} van {{total}} codes zijn gebruikt.",
    "Nextcloud backup codes" : "Nextcloud backup codes",
    "activated" : "geactiveerd",
    "updated" : "geüpdatet",
    "mounted" : "aangekoppeld",
    "deactivated" : "uitgeschakeld",
    "beforeCreate" : "beforeCreate",
    "created" : "gecreëerd",
    "beforeUpdate" : "beforeUpdate",
    "beforeDestroy" : "beforeDestroy",
    "destroyed" : "vernietigd",
    "beforeMount" : "beforeMount"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/nl.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "An error occurred while generating your backup codes" : "Er trad een fout op bij het genereren van je backup codes",
    "{name} backup codes" : "{naam} backup codes",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Dit zijn je back-upcodes. Bewaar ze en/of druk ze alsjeblieft af, want je ze niet later nog een keer opvragen.",
    "Save backup codes" : "Bewaren backup code",
    "Print backup codes" : "Afdrukken backup code",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Backup codes zijn gegenereerd. {used} van {{total}} codes zijn gebruikt.",
    "Regenerate backup codes" : "Regenereer backup code",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "Als je backup codes opnieuw genereert, worden oude codes automatisch ongeldig gemaakt.",
    "Generate backup codes" : "Genereer backup code",
    "You created two-factor backup codes for your account" : "Je creëerde tweefactor back-up codes voor je account",
    "Second-factor backup codes" : "Twee-factor backup code",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Je hebt tweefactor authenticatie ingeschakeld, maar nog geen backup codes gegenereerd. Die zijn nodig voor het ontsluiten van je account, in het geval dat je je tweede factor kwijt bent.",
    "Backup code" : "Backup code",
    "Use backup code" : "Gebruik backup code",
    "Two factor backup codes" : "Twee-factor backupcode",
    "A two-factor auth backup codes provider" : "Een two-factor auth backup codes provider",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Gebruik een van de backupcodes die je bewaarde bij het inschakelen van de twee-factor authenticatie.",
    "Submit" : "Verwerken",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Backup codes zijn gegenereerd. {{used}} van {{total}} codes zijn gebruikt.",
    "Nextcloud backup codes" : "Nextcloud backup codes",
    "activated" : "geactiveerd",
    "updated" : "geüpdatet",
    "mounted" : "aangekoppeld",
    "deactivated" : "uitgeschakeld",
    "beforeCreate" : "beforeCreate",
    "created" : "gecreëerd",
    "beforeUpdate" : "beforeUpdate",
    "beforeDestroy" : "beforeDestroy",
    "destroyed" : "vernietigd",
    "beforeMount" : "beforeMount",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Je hebt tweefactor authenticatie ingeschakeld, maar nog geen backup codes gegenereerd. Doe dat eerst, voor het geval dat je toegang tot je tweede factor apparaat kwijt bent."
},
"nplurals=2; plural=(n != 1);");
